@@ -40,62 +40,62 @@ static digr_T digraphdefault[] =
 	 * ATARI digraphs
 	 */
        {{'C', ',', 128},	/* ~@ XX */
-	{'u', '"', 129},	/*  */
-	{'e', '\'', 130},	/*  */
-	{'a', '^', 131},	/*  */
-	{'a', '"', 132},	/*  */
-	{'a', '`', 133},	/*  */
-	{'a', '@', 134},	/*  */
+	{'u', '"', 129},	/*  */
+	{'e', '\'', 130},	/*  */
+	{'a', '^', 131},	/*  */
+	{'a', '"', 132},	/*  */
+	{'a', '`', 133},	/*  */
+	{'a', '@', 134},	/*  */
 	{'c', ',', 135},	/* ~G XX */
 	{'e', '^', 136},	/* ~H XX */
-	{'e', '"', 137},	/*  */
-	{'e', '`', 138},	/*  */
-	{'i', '"', 139},	/*  */
-	{'i', '^', 140},	/*  */
-	{'i', '`', 141},	/*  */
-	{'A', '"', 142},	/*  */
-	{'A', '@', 143},	/*  */
-	{'E', '\'', 144},	/*  */
-	{'a', 'e', 145},	/*  */
-	{'A', 'E', 146},	/*  */
-	{'o', '^', 147},	/*  */
-	{'o', '"', 148},	/*  */
-	{'o', '`', 149},	/*  */
-	{'u', '^', 150},	/*  */
-	{'u', '`', 151},	/*  */
-	{'y', '"', 152},	/*  */
-	{'O', '"', 153},	/*  */
-	{'U', '"', 154},	/*  */
-	{'c', '|', 155},	/*  */
-	{'$', '$', 156},	/*  */
+	{'e', '"', 137},	/*  */
+	{'e', '`', 138},	/*  */
+	{'i', '"', 139},	/*  */
+	{'i', '^', 140},	/*  */
+	{'i', '`', 141},	/*  */
+	{'A', '"', 142},	/*  */
+	{'A', '@', 143},	/*  */
+	{'E', '\'', 144},	/*  */
+	{'a', 'e', 145},	/*  */
+	{'A', 'E', 146},	/*  */
+	{'o', '^', 147},	/*  */
+	{'o', '"', 148},	/*  */
+	{'o', '`', 149},	/*  */
+	{'u', '^', 150},	/*  */
+	{'u', '`', 151},	/*  */
+	{'y', '"', 152},	/*  */
+	{'O', '"', 153},	/*  */
+	{'U', '"', 154},	/*  */
+	{'c', '|', 155},	/*  */
+	{'$', '$', 156},	/*  */
 	{'Y', '-', 157},	/* ~] XX */
-	{'s', 's', 158},	/*  */
-	{'f', 'f', 159},	/*  */
-	{'a', '\'', 160},	/*  */
-	{'i', '\'', 161},	/*  */
-	{'o', '\'', 162},	/*  */
-	{'u', '\'', 163},	/*  */
-	{'n', '~', 164},	/*  */
-	{'N', '~', 165},	/*  */
-	{'a', 'a', 166},	/*  */
-	{'o', 'o', 167},	/*  */
-	{'~', '?', 168},	/*  */
-	{'-', 'a', 169},	/*  */
-	{'a', '-', 170},	/*  */
-	{'1', '2', 171},	/*  */
-	{'1', '4', 172},	/*  */
-	{'~', '!', 173},	/*  */
-	{'<', '<', 174},	/*  */
-	{'>', '>', 175},	/*  */
-	{'j', 'u', 230},	/*  */
-	{'o', '/', 237},	/*  */
-	{'+', '-', 241},	/*  */
-	{'>', '=', 242},	/*  */
-	{'<', '=', 243},	/*  */
-	{':', '-', 246},	/*  */
-	{'~', '~', 247},	/*  */
-	{'~', 'o', 248},	/*  */
-	{'2', '2', 253},	/*  */
+	{'s', 's', 158},	/*  */
+	{'f', 'f', 159},	/*  */
+	{'a', '\'', 160},	/*   */
+	{'i', '\'', 161},	/* ¡ */
+	{'o', '\'', 162},	/* ¢ */
+	{'u', '\'', 163},	/* £ */
+	{'n', '~', 164},	/* ¤ */
+	{'N', '~', 165},	/* ¥ */
+	{'a', 'a', 166},	/* ¦ */
+	{'o', 'o', 167},	/* § */
+	{'~', '?', 168},	/* ¨ */
+	{'-', 'a', 169},	/* © */
+	{'a', '-', 170},	/* ª */
+	{'1', '2', 171},	/* « */
+	{'1', '4', 172},	/* ¬ */
+	{'~', '!', 173},	/* ­ */
+	{'<', '<', 174},	/* ® */
+	{'>', '>', 175},	/* ¯ */
+	{'j', 'u', 230},	/* æ */
+	{'o', '/', 237},	/* í */
+	{'+', '-', 241},	/* ñ */
+	{'>', '=', 242},	/* ò */
+	{'<', '=', 243},	/* ó */
+	{':', '-', 246},	/* ö */
+	{'~', '~', 247},	/* ÷ */
+	{'~', 'o', 248},	/* ø */
+	{'2', '2', 253},	/* ý */
 	{NUL, NUL, NUL}
 	};
 
@@ -105,100 +105,100 @@ static digr_T digraphdefault[] =
 	/*
 	 * different HPUX digraphs
 	 */
-       {{'A', '`', 161},	/*  */
-	{'A', '^', 162},	/*  */
-	{'E', '`', 163},	/*  */
-	{'E', '^', 164},	/*  */
-	{'E', '"', 165},	/*  */
-	{'I', '^', 166},	/*  */
-	{'I', '"', 167},	/*  */
-	{'\'', '\'', 168},	/*  */
-	{'`', '`', 169},	/*  */
-	{'^', '^', 170},	/*  */
-	{'"', '"', 171},	/*  */
-	{'~', '~', 172},	/*  */
-	{'U', '`', 173},	/*  */
-	{'U', '^', 174},	/*  */
-	{'L', '=', 175},	/*  */
-	{'~', '_', 176},	/*  */
-	{'Y', '\'', 177},	/*  */
-	{'y', '\'', 178},	/*  */
-	{'~', 'o', 179},	/*  */
-	{'C', ',', 180},	/*  */
-	{'c', ',', 181},	/*  */
-	{'N', '~', 182},	/*  */
-	{'n', '~', 183},	/*  */
-	{'~', '!', 184},	/*  */
-	{'~', '?', 185},	/*  */
-	{'o', 'x', 186},	/*  */
-	{'L', '-', 187},	/*  */
-	{'Y', '=', 188},	/*  */
-	{'p', 'p', 189},	/*  */
-	{'f', 'l', 190},	/*  */
-	{'c', '|', 191},	/*  */
-	{'a', '^', 192},	/*  */
-	{'e', '^', 193},	/*  */
-	{'o', '^', 194},	/*  */
-	{'u', '^', 195},	/*  */
-	{'a', '\'', 196},	/*  */
-	{'e', '\'', 197},	/*  */
-	{'o', '\'', 198},	/*  */
-	{'u', '\'', 199},	/*  */
-	{'a', '`', 200},	/*  */
-	{'e', '`', 201},	/*  */
-	{'o', '`', 202},	/*  */
-	{'u', '`', 203},	/*  */
-	{'a', '"', 204},	/*  */
-	{'e', '"', 205},	/*  */
-	{'o', '"', 206},	/*  */
-	{'u', '"', 207},	/*  */
-	{'A', 'o', 208},	/*  */
-	{'i', '^', 209},	/*  */
-	{'O', '/', 210},	/*  */
-	{'A', 'E', 211},	/*  */
-	{'a', 'o', 212},	/*  */
-	{'i', '\'', 213},	/*  */
-	{'o', '/', 214},	/*  */
-	{'a', 'e', 215},	/*  */
-	{'A', '"', 216},	/*  */
-	{'i', '`', 217},	/*  */
-	{'O', '"', 218},	/*  */
-	{'U', '"', 219},	/*  */
-	{'E', '\'', 220},	/*  */
-	{'i', '"', 221},	/*  */
-	{'s', 's', 222},	/*  */
-	{'O', '^', 223},	/*  */
-	{'A', '\'', 224},	/*  */
-	{'A', '~', 225},	/*  */
-	{'a', '~', 226},	/*  */
-	{'D', '-', 227},	/*  */
-	{'d', '-', 228},	/*  */
-	{'I', '\'', 229},	/*  */
-	{'I', '`', 230},	/*  */
-	{'O', '\'', 231},	/*  */
-	{'O', '`', 232},	/*  */
-	{'O', '~', 233},	/*  */
-	{'o', '~', 234},	/*  */
-	{'S', '~', 235},	/*  */
-	{'s', '~', 236},	/*  */
-	{'U', '\'', 237},	/*  */
-	{'Y', '"', 238},	/*  */
-	{'y', '"', 239},	/*  */
-	{'p', '-', 240},	/*  */
-	{'p', '~', 241},	/*  */
-	{'~', '.', 242},	/*  */
-	{'j', 'u', 243},	/*  */
-	{'P', 'p', 244},	/*  */
-	{'3', '4', 245},	/*  */
-	{'-', '-', 246},	/*  */
-	{'1', '4', 247},	/*  */
-	{'1', '2', 248},	/*  */
-	{'a', '_', 249},	/*  */
-	{'o', '_', 250},	/*  */
-	{'<', '<', 251},	/*  */
-	{'x', 'x', 252},	/*  */
-	{'>', '>', 253},	/*  */
-	{'+', '-', 254},	/*  */
+       {{'A', '`', 161},	/* ¡ */
+	{'A', '^', 162},	/* ¢ */
+	{'E', '`', 163},	/* £ */
+	{'E', '^', 164},	/* ¤ */
+	{'E', '"', 165},	/* ¥ */
+	{'I', '^', 166},	/* ¦ */
+	{'I', '"', 167},	/* § */
+	{'\'', '\'', 168},	/* ¨ */
+	{'`', '`', 169},	/* © */
+	{'^', '^', 170},	/* ª */
+	{'"', '"', 171},	/* « */
+	{'~', '~', 172},	/* ¬ */
+	{'U', '`', 173},	/* ­ */
+	{'U', '^', 174},	/* ® */
+	{'L', '=', 175},	/* ¯ */
+	{'~', '_', 176},	/* ° */
+	{'Y', '\'', 177},	/* ± */
+	{'y', '\'', 178},	/* ² */
+	{'~', 'o', 179},	/* ³ */
+	{'C', ',', 180},	/* ´ */
+	{'c', ',', 181},	/* µ */
+	{'N', '~', 182},	/* ¶ */
+	{'n', '~', 183},	/* · */
+	{'~', '!', 184},	/* ¸ */
+	{'~', '?', 185},	/* ¹ */
+	{'o', 'x', 186},	/* º */
+	{'L', '-', 187},	/* » */
+	{'Y', '=', 188},	/* ¼ */
+	{'p', 'p', 189},	/* ½ */
+	{'f', 'l', 190},	/* ¾ */
+	{'c', '|', 191},	/* ¿ */
+	{'a', '^', 192},	/* À */
+	{'e', '^', 193},	/* Á */
+	{'o', '^', 194},	/* Â */
+	{'u', '^', 195},	/* Ã */
+	{'a', '\'', 196},	/* Ä */
+	{'e', '\'', 197},	/* Å */
+	{'o', '\'', 198},	/* Æ */
+	{'u', '\'', 199},	/* Ç */
+	{'a', '`', 200},	/* È */
+	{'e', '`', 201},	/* É */
+	{'o', '`', 202},	/* Ê */
+	{'u', '`', 203},	/* Ë */
+	{'a', '"', 204},	/* Ì */
+	{'e', '"', 205},	/* Í */
+	{'o', '"', 206},	/* Î */
+	{'u', '"', 207},	/* Ï */
+	{'A', 'o', 208},	/* Ð */
+	{'i', '^', 209},	/* Ñ */
+	{'O', '/', 210},	/* Ò */
+	{'A', 'E', 211},	/* Ó */
+	{'a', 'o', 212},	/* Ô */
+	{'i', '\'', 213},	/* Õ */
+	{'o', '/', 214},	/* Ö */
+	{'a', 'e', 215},	/* × */
+	{'A', '"', 216},	/* Ø */
+	{'i', '`', 217},	/* Ù */
+	{'O', '"', 218},	/* Ú */
+	{'U', '"', 219},	/* Û */
+	{'E', '\'', 220},	/* Ü */
+	{'i', '"', 221},	/* Ý */
+	{'s', 's', 222},	/* Þ */
+	{'O', '^', 223},	/* ß */
+	{'A', '\'', 224},	/* à */
+	{'A', '~', 225},	/* á */
+	{'a', '~', 226},	/* â */
+	{'D', '-', 227},	/* ã */
+	{'d', '-', 228},	/* ä */
+	{'I', '\'', 229},	/* å */
+	{'I', '`', 230},	/* æ */
+	{'O', '\'', 231},	/* ç */
+	{'O', '`', 232},	/* è */
+	{'O', '~', 233},	/* é */
+	{'o', '~', 234},	/* ê */
+	{'S', '~', 235},	/* ë */
+	{'s', '~', 236},	/* ì */
+	{'U', '\'', 237},	/* í */
+	{'Y', '"', 238},	/* î */
+	{'y', '"', 239},	/* ï */
+	{'p', '-', 240},	/* ð */
+	{'p', '~', 241},	/* ñ */
+	{'~', '.', 242},	/* ò */
+	{'j', 'u', 243},	/* ó */
+	{'P', 'p', 244},	/* ô */
+	{'3', '4', 245},	/* õ */
+	{'-', '-', 246},	/* ö */
+	{'1', '4', 247},	/* ÷ */
+	{'1', '2', 248},	/* ø */
+	{'a', '_', 249},	/* ù */
+	{'o', '_', 250},	/* ú */
+	{'<', '<', 251},	/* û */
+	{'x', 'x', 252},	/* ü */
+	{'>', '>', 253},	/* ý */
+	{'+', '-', 254},	/* þ */
 	{'n', 'u', 255},	/* x XX */
 	{NUL, NUL, NUL}
 	};
@@ -211,107 +211,107 @@ static digr_T digraphdefault[] =
 	 * EBCDIC - ISO digraphs
 	 * TODO: EBCDIC Table is Code-Page 1047
 	 */
-       {{'a', '^',    66},	/*  */
-	{'a', '"',    67},	/*  */
-	{'a', '`',    68},	/*  */
-	{'a', '\'',   69},	/*  */
-	{'a', '~',    70},	/*  */
-	{'a', '@',    71},	/*  */
-	{'a', 'a',    71},	/*  */
-	{'c', ',',    72},	/*  */
-	{'n', '~',    73},	/*  */
-	{'c', '|',    74},	/*  */
-	{'e', '\'',   81},	/*  */
-	{'e', '^',    82},	/*  */
-	{'e', '"',    83},	/*  */
-	{'e', '`',    84},	/*  */
-	{'i', '\'',   85},	/*  */
-	{'i', '^',    86},	/*  */
-	{'i', '"',    87},	/*  */
-	{'i', '`',    88},	/*  */
-	{'s', 's',    89},	/*  */
-	{'A', '^',    98},	/*  */
-	{'A', '"',    99},	/*  */
-	{'A', '`',   100},	/*  */
-	{'A', '\'',  101},	/*  */
-	{'A', '~',   102},	/*  */
-	{'A', '@',   103},	/*  */
-	{'A', 'A',   103},	/*  */
-	{'C', ',',   104},	/*  */
-	{'N', '~',   105},	/*  */
-	{'|', '|',   106},	/*  */
-	{'o', '/',   112},	/*  */
-	{'E', '\'',  113},	/*  */
-	{'E', '^',   114},	/*  */
-	{'E', '"',   115},	/*  */
-	{'E', '`',   116},	/*  */
-	{'I', '\'',  117},	/*  */
-	{'I', '^',   118},	/*  */
-	{'I', '"',   119},	/*  */
-	{'I', '`',   120},	/*  */
+       {{'a', '^',    66},	/* â */
+	{'a', '"',    67},	/* ä */
+	{'a', '`',    68},	/* à */
+	{'a', '\'',   69},	/* á */
+	{'a', '~',    70},	/* ã */
+	{'a', '@',    71},	/* å */
+	{'a', 'a',    71},	/* å */
+	{'c', ',',    72},	/* ç */
+	{'n', '~',    73},	/* ñ */
+	{'c', '|',    74},	/* ¢ */
+	{'e', '\'',   81},	/* é */
+	{'e', '^',    82},	/* ê */
+	{'e', '"',    83},	/* ë */
+	{'e', '`',    84},	/* è */
+	{'i', '\'',   85},	/* í */
+	{'i', '^',    86},	/* î */
+	{'i', '"',    87},	/* ï */
+	{'i', '`',    88},	/* ì */
+	{'s', 's',    89},	/* ß */
+	{'A', '^',    98},	/* Â */
+	{'A', '"',    99},	/* Ä */
+	{'A', '`',   100},	/* À */
+	{'A', '\'',  101},	/* Á */
+	{'A', '~',   102},	/* Ã */
+	{'A', '@',   103},	/* Å */
+	{'A', 'A',   103},	/* Å */
+	{'C', ',',   104},	/* Ç */
+	{'N', '~',   105},	/* Ñ */
+	{'|', '|',   106},	/* ¦ */
+	{'o', '/',   112},	/* ø */
+	{'E', '\'',  113},	/* É */
+	{'E', '^',   114},	/* Ê */
+	{'E', '"',   115},	/* Ë */
+	{'E', '`',   116},	/* È */
+	{'I', '\'',  117},	/* Í */
+	{'I', '^',   118},	/* Î */
+	{'I', '"',   119},	/* Ï */
+	{'I', '`',   120},	/* Ì */
 	{'O', '/',   128},	/* 0/ XX */
-	{'<', '<',   138},	/*  */
-	{'>', '>',   139},	/*  */
-	{'d', '-',   140},	/*  */
-	{'y', '\'',  141},	/*  */
-	{'i', 'p',   142},	/*  */
-	{'+', '-',   143},	/*  */
-	{'~', 'o',   144},	/*  */
-	{'a', '-',   154},	/*  */
-	{'o', '-',   155},	/*  */
-	{'a', 'e',   156},	/*  */
+	{'<', '<',   138},	/* « */
+	{'>', '>',   139},	/* » */
+	{'d', '-',   140},	/* ð */
+	{'y', '\'',  141},	/* ý */
+	{'i', 'p',   142},	/* þ */
+	{'+', '-',   143},	/* ± */
+	{'~', 'o',   144},	/* ° */
+	{'a', '-',   154},	/* ª */
+	{'o', '-',   155},	/* º */
+	{'a', 'e',   156},	/* æ */
 	{',', ',',   157},	/* , XX */
-	{'A', 'E',   158},	/*  */
-	{'o', 'x',   159},	/*  - currency symbol in ISO 8859-1 */
-	{'e', '=',   159},	/*  - euro symbol in ISO 8859-15 */
-	{'E', 'u',   159},	/*  - euro symbol in ISO 8859-15 */
-	{'j', 'u',   160},	/*  */
+	{'A', 'E',   158},	/* Æ */
+	{'o', 'x',   159},	/* ¤ - currency symbol in ISO 8859-1 */
+	{'e', '=',   159},	/* ¤ - euro symbol in ISO 8859-15 */
+	{'E', 'u',   159},	/* ¤ - euro symbol in ISO 8859-15 */
+	{'j', 'u',   160},	/* µ */
 	{'y', '"',   167},	/* x XX */
-	{'~', '!',   170},	/*  */
-	{'~', '?',   171},	/*  */
-	{'D', '-',   172},	/*  */
-	{'I', 'p',   174},	/*  */
-	{'r', 'O',   175},	/*  */
-	{'-', ',',   176},	/*  */
-	{'$', '$',   177},	/*  */
-	{'Y', '-',   178},	/*  */
-	{'~', '.',   179},	/*  */
-	{'c', 'O',   180},	/*  */
-	{'p', 'a',   181},	/*  */
-	{'p', 'p',   182},	/*  */
-	{'1', '4',   183},	/*  */
-	{'1', '2',   184},	/*  */
-	{'3', '4',   185},	/*  */
-	{'Y', '\'',  186},	/*  */
-	{'"', '"',   187},	/*  */
-	{'-', '=',   188},	/*  */
-	{'\'', '\'', 190},	/*  */
-	{'O', 'E',   191},	/*  - OE in ISO 8859-15 */
-	{'/', '\\',  191},	/*  - multiplication symbol in ISO 8859-1 */
-	{'-', '-',   202},	/*  */
-	{'o', '^',   203},	/*  */
-	{'o', '"',   204},	/*  */
-	{'o', '`',   205},	/*  */
-	{'o', '\'',  206},	/*  */
-	{'o', '~',   207},	/*  */
-	{'1', '1',   218},	/*  */
-	{'u', '^',   219},	/*  */
-	{'u', '"',   220},	/*  */
-	{'u', '`',   221},	/*  */
-	{'u', '\'',  222},	/*  */
-	{':', '-',   225},	/*  - division symbol in ISO 8859-1 */
-	{'o', 'e',   225},	/*  - oe in ISO 8859-15 */
-	{'2', '2',   234},	/*  */
-	{'O', '^',   235},	/*  */
-	{'O', '"',   236},	/*  */
-	{'O', '`',   237},	/*  */
-	{'O', '\'',  238},	/*  */
-	{'O', '~',   239},	/*  */
-	{'3', '3',   250},	/*  */
-	{'U', '^',   251},	/*  */
-	{'U', '"',   252},	/*  */
-	{'U', '`',   253},	/*  */
-	{'U', '\'',  254},	/*  */
+	{'~', '!',   170},	/* ¡ */
+	{'~', '?',   171},	/* ¿ */
+	{'D', '-',   172},	/* Ð */
+	{'I', 'p',   174},	/* Þ */
+	{'r', 'O',   175},	/* ® */
+	{'-', ',',   176},	/* ¬ */
+	{'$', '$',   177},	/* £ */
+	{'Y', '-',   178},	/* ¥ */
+	{'~', '.',   179},	/* · */
+	{'c', 'O',   180},	/* © */
+	{'p', 'a',   181},	/* § */
+	{'p', 'p',   182},	/* ¶ */
+	{'1', '4',   183},	/* ¼ */
+	{'1', '2',   184},	/* ½ */
+	{'3', '4',   185},	/* ¾ */
+	{'Y', '\'',  186},	/* Ý */
+	{'"', '"',   187},	/* ¨ */
+	{'-', '=',   188},	/* ¯ */
+	{'\'', '\'', 190},	/* ´ */
+	{'O', 'E',   191},	/* × - OE in ISO 8859-15 */
+	{'/', '\\',  191},	/* × - multiplication symbol in ISO 8859-1 */
+	{'-', '-',   202},	/* ­ */
+	{'o', '^',   203},	/* ô */
+	{'o', '"',   204},	/* ö */
+	{'o', '`',   205},	/* ò */
+	{'o', '\'',  206},	/* ó */
+	{'o', '~',   207},	/* õ */
+	{'1', '1',   218},	/* ¹ */
+	{'u', '^',   219},	/* û */
+	{'u', '"',   220},	/* ü */
+	{'u', '`',   221},	/* ù */
+	{'u', '\'',  222},	/* ú */
+	{':', '-',   225},	/* ÷ - division symbol in ISO 8859-1 */
+	{'o', 'e',   225},	/* ÷ - oe in ISO 8859-15 */
+	{'2', '2',   234},	/* ² */
+	{'O', '^',   235},	/* Ô */
+	{'O', '"',   236},	/* Ö */
+	{'O', '`',   237},	/* Ò */
+	{'O', '\'',  238},	/* Ó */
+	{'O', '~',   239},	/* Õ */
+	{'3', '3',   250},	/* ³ */
+	{'U', '^',   251},	/* Û */
+	{'U', '"',   252},	/* Ü */
+	{'U', '`',   253},	/* Ù */
+	{'U', '\'',  254},	/* Ú */
 	{NUL, NUL, NUL}
 	};
 
@@ -321,105 +321,105 @@ static digr_T digraphdefault[] =
 	/*
 	 * digraphs compatible with Vim 5.x
 	 */
-       {{'~', '!', 161},	/*  */
-	{'c', '|', 162},	/*  */
-	{'$', '$', 163},	/*  */
-	{'o', 'x', 164},	/*  - currency symbol in ISO 8859-1 */
-	{'e', '=', 164},	/*  - euro symbol in ISO 8859-15 */
-	{'Y', '-', 165},	/*  */
-	{'|', '|', 166},	/*  */
-	{'p', 'a', 167},	/*  */
-	{'"', '"', 168},	/*  */
-	{'c', 'O', 169},	/*  */
-	{'a', '-', 170},	/*  */
-	{'<', '<', 171},	/*  */
-	{'-', ',', 172},	/*  */
-	{'-', '-', 173},	/*  */
-	{'r', 'O', 174},	/*  */
-	{'-', '=', 175},	/*  */
-	{'~', 'o', 176},	/*  */
-	{'+', '-', 177},	/*  */
-	{'2', '2', 178},	/*  */
-	{'3', '3', 179},	/*  */
-	{'\'', '\'', 180},	/*  */
-	{'j', 'u', 181},	/*  */
-	{'p', 'p', 182},	/*  */
-	{'~', '.', 183},	/*  */
-	{',', ',', 184},	/*  */
-	{'1', '1', 185},	/*  */
-	{'o', '-', 186},	/*  */
-	{'>', '>', 187},	/*  */
-	{'1', '4', 188},	/*  */
-	{'1', '2', 189},	/*  */
-	{'3', '4', 190},	/*  */
-	{'~', '?', 191},	/*  */
-	{'A', '`', 192},	/*  */
-	{'A', '\'', 193},	/*  */
-	{'A', '^', 194},	/*  */
-	{'A', '~', 195},	/*  */
-	{'A', '"', 196},	/*  */
-	{'A', '@', 197},	/*  */
-	{'A', 'A', 197},	/*  */
-	{'A', 'E', 198},	/*  */
-	{'C', ',', 199},	/*  */
-	{'E', '`', 200},	/*  */
-	{'E', '\'', 201},	/*  */
-	{'E', '^', 202},	/*  */
-	{'E', '"', 203},	/*  */
-	{'I', '`', 204},	/*  */
-	{'I', '\'', 205},	/*  */
-	{'I', '^', 206},	/*  */
-	{'I', '"', 207},	/*  */
-	{'D', '-', 208},	/*  */
-	{'N', '~', 209},	/*  */
-	{'O', '`', 210},	/*  */
-	{'O', '\'', 211},	/*  */
-	{'O', '^', 212},	/*  */
-	{'O', '~', 213},	/*  */
-	{'O', '"', 214},	/*  */
-	{'/', '\\', 215},	/*  - multiplication symbol in ISO 8859-1 */
-	{'O', 'E', 215},	/*  - OE in ISO 8859-15 */
-	{'O', '/', 216},	/*  */
-	{'U', '`', 217},	/*  */
-	{'U', '\'', 218},	/*  */
-	{'U', '^', 219},	/*  */
-	{'U', '"', 220},	/*  */
-	{'Y', '\'', 221},	/*  */
-	{'I', 'p', 222},	/*  */
-	{'s', 's', 223},	/*  */
-	{'a', '`', 224},	/*  */
-	{'a', '\'', 225},	/*  */
-	{'a', '^', 226},	/*  */
-	{'a', '~', 227},	/*  */
-	{'a', '"', 228},	/*  */
-	{'a', '@', 229},	/*  */
-	{'a', 'a', 229},	/*  */
-	{'a', 'e', 230},	/*  */
-	{'c', ',', 231},	/*  */
-	{'e', '`', 232},	/*  */
-	{'e', '\'', 233},	/*  */
-	{'e', '^', 234},	/*  */
-	{'e', '"', 235},	/*  */
-	{'i', '`', 236},	/*  */
-	{'i', '\'', 237},	/*  */
-	{'i', '^', 238},	/*  */
-	{'i', '"', 239},	/*  */
-	{'d', '-', 240},	/*  */
-	{'n', '~', 241},	/*  */
-	{'o', '`', 242},	/*  */
-	{'o', '\'', 243},	/*  */
-	{'o', '^', 244},	/*  */
-	{'o', '~', 245},	/*  */
-	{'o', '"', 246},	/*  */
-	{':', '-', 247},	/*  - division symbol in ISO 8859-1 */
-	{'o', 'e', 247},	/*  - oe in ISO 8859-15 */
-	{'o', '/', 248},	/*  */
-	{'u', '`', 249},	/*  */
-	{'u', '\'', 250},	/*  */
-	{'u', '^', 251},	/*  */
-	{'u', '"', 252},	/*  */
-	{'y', '\'', 253},	/*  */
-	{'i', 'p', 254},	/*  */
+       {{'~', '!', 161},	/* ¡ */
+	{'c', '|', 162},	/* ¢ */
+	{'$', '$', 163},	/* £ */
+	{'o', 'x', 164},	/* ¤ - currency symbol in ISO 8859-1 */
+	{'e', '=', 164},	/* ¤ - euro symbol in ISO 8859-15 */
+	{'Y', '-', 165},	/* ¥ */
+	{'|', '|', 166},	/* ¦ */
+	{'p', 'a', 167},	/* § */
+	{'"', '"', 168},	/* ¨ */
+	{'c', 'O', 169},	/* © */
+	{'a', '-', 170},	/* ª */
+	{'<', '<', 171},	/* « */
+	{'-', ',', 172},	/* ¬ */
+	{'-', '-', 173},	/* ­ */
+	{'r', 'O', 174},	/* ® */
+	{'-', '=', 175},	/* ¯ */
+	{'~', 'o', 176},	/* ° */
+	{'+', '-', 177},	/* ± */
+	{'2', '2', 178},	/* ² */
+	{'3', '3', 179},	/* ³ */
+	{'\'', '\'', 180},	/* ´ */
+	{'j', 'u', 181},	/* µ */
+	{'p', 'p', 182},	/* ¶ */
+	{'~', '.', 183},	/* · */
+	{',', ',', 184},	/* ¸ */
+	{'1', '1', 185},	/* ¹ */
+	{'o', '-', 186},	/* º */
+	{'>', '>', 187},	/* » */
+	{'1', '4', 188},	/* ¼ */
+	{'1', '2', 189},	/* ½ */
+	{'3', '4', 190},	/* ¾ */
+	{'~', '?', 191},	/* ¿ */
+	{'A', '`', 192},	/* À */
+	{'A', '\'', 193},	/* Á */
+	{'A', '^', 194},	/* Â */
+	{'A', '~', 195},	/* Ã */
+	{'A', '"', 196},	/* Ä */
+	{'A', '@', 197},	/* Å */
+	{'A', 'A', 197},	/* Å */
+	{'A', 'E', 198},	/* Æ */
+	{'C', ',', 199},	/* Ç */
+	{'E', '`', 200},	/* È */
+	{'E', '\'', 201},	/* É */
+	{'E', '^', 202},	/* Ê */
+	{'E', '"', 203},	/* Ë */
+	{'I', '`', 204},	/* Ì */
+	{'I', '\'', 205},	/* Í */
+	{'I', '^', 206},	/* Î */
+	{'I', '"', 207},	/* Ï */
+	{'D', '-', 208},	/* Ð */
+	{'N', '~', 209},	/* Ñ */
+	{'O', '`', 210},	/* Ò */
+	{'O', '\'', 211},	/* Ó */
+	{'O', '^', 212},	/* Ô */
+	{'O', '~', 213},	/* Õ */
+	{'O', '"', 214},	/* Ö */
+	{'/', '\\', 215},	/* × - multiplication symbol in ISO 8859-1 */
+	{'O', 'E', 215},	/* × - OE in ISO 8859-15 */
+	{'O', '/', 216},	/* Ø */
+	{'U', '`', 217},	/* Ù */
+	{'U', '\'', 218},	/* Ú */
+	{'U', '^', 219},	/* Û */
+	{'U', '"', 220},	/* Ü */
+	{'Y', '\'', 221},	/* Ý */
+	{'I', 'p', 222},	/* Þ */
+	{'s', 's', 223},	/* ß */
+	{'a', '`', 224},	/* à */
+	{'a', '\'', 225},	/* á */
+	{'a', '^', 226},	/* â */
+	{'a', '~', 227},	/* ã */
+	{'a', '"', 228},	/* ä */
+	{'a', '@', 229},	/* å */
+	{'a', 'a', 229},	/* å */
+	{'a', 'e', 230},	/* æ */
+	{'c', ',', 231},	/* ç */
+	{'e', '`', 232},	/* è */
+	{'e', '\'', 233},	/* é */
+	{'e', '^', 234},	/* ê */
+	{'e', '"', 235},	/* ë */
+	{'i', '`', 236},	/* ì */
+	{'i', '\'', 237},	/* í */
+	{'i', '^', 238},	/* î */
+	{'i', '"', 239},	/* ï */
+	{'d', '-', 240},	/* ð */
+	{'n', '~', 241},	/* ñ */
+	{'o', '`', 242},	/* ò */
+	{'o', '\'', 243},	/* ó */
+	{'o', '^', 244},	/* ô */
+	{'o', '~', 245},	/* õ */
+	{'o', '"', 246},	/* ö */
+	{':', '-', 247},	/* ÷ - division symbol in ISO 8859-1 */
+	{'o', 'e', 247},	/* ÷ - oe in ISO 8859-15 */
+	{'o', '/', 248},	/* ø */
+	{'u', '`', 249},	/* ù */
+	{'u', '\'', 250},	/* ú */
+	{'u', '^', 251},	/* û */
+	{'u', '"', 252},	/* ü */
+	{'y', '\'', 253},	/* ý */
+	{'i', 'p', 254},	/* þ */
 	{'y', '"', 255},	/* x XX */
 	{NUL, NUL, NUL}
 	};
@@ -511,147 +511,147 @@ static digr_T digraphdefault[] =
 	{'N', 'S', 0xa0},
 #define DG_START_LATIN 0xa1
 	{'!', 'I', 0xa1},
-	{'~', '!', 0xa1},	//  Vim 5.x compatible
+	{'~', '!', 0xa1},	// ¡ Vim 5.x compatible
 	{'C', 't', 0xa2},
-	{'c', '|', 0xa2},	//  Vim 5.x compatible
+	{'c', '|', 0xa2},	// ¢ Vim 5.x compatible
 	{'P', 'd', 0xa3},
-	{'$', '$', 0xa3},	//  Vim 5.x compatible
+	{'$', '$', 0xa3},	// £ Vim 5.x compatible
 	{'C', 'u', 0xa4},
-	{'o', 'x', 0xa4},	//  Vim 5.x compatible
+	{'o', 'x', 0xa4},	// ¤ Vim 5.x compatible
 	{'Y', 'e', 0xa5},
-	{'Y', '-', 0xa5},	//  Vim 5.x compatible
+	{'Y', '-', 0xa5},	// ¥ Vim 5.x compatible
 	{'B', 'B', 0xa6},
-	{'|', '|', 0xa6},	//  Vim 5.x compatible
+	{'|', '|', 0xa6},	// ¦ Vim 5.x compatible
 	{'S', 'E', 0xa7},
 	{'\'', ':', 0xa8},
 	{'C', 'o', 0xa9},
-	{'c', 'O', 0xa9},	//  Vim 5.x compatible
+	{'c', 'O', 0xa9},	// © Vim 5.x compatible
 	{'-', 'a', 0xaa},
 	{'<', '<', 0xab},
 	{'N', 'O', 0xac},
-	{'-', ',', 0xac},	//  Vim 5.x compatible
+	{'-', ',', 0xac},	// ¬ Vim 5.x compatible
 	{'-', '-', 0xad},
 	{'R', 'g', 0xae},
 	{'\'', 'm', 0xaf},
-	{'-', '=', 0xaf},	//  Vim 5.x compatible
+	{'-', '=', 0xaf},	// ¯ Vim 5.x compatible
 	{'D', 'G', 0xb0},
-	{'~', 'o', 0xb0},	//  Vim 5.x compatible
+	{'~', 'o', 0xb0},	// ° Vim 5.x compatible
 	{'+', '-', 0xb1},
 	{'2', 'S', 0xb2},
-	{'2', '2', 0xb2},	//  Vim 5.x compatible
+	{'2', '2', 0xb2},	// ² Vim 5.x compatible
 	{'3', 'S', 0xb3},
-	{'3', '3', 0xb3},	//  Vim 5.x compatible
+	{'3', '3', 0xb3},	// ³ Vim 5.x compatible
 	{'\'', '\'', 0xb4},
 	{'M', 'y', 0xb5},
 	{'P', 'I', 0xb6},
-	{'p', 'p', 0xb6},	//  Vim 5.x compatible
+	{'p', 'p', 0xb6},	// ¶ Vim 5.x compatible
 	{'.', 'M', 0xb7},
-	{'~', '.', 0xb7},	//  Vim 5.x compatible
+	{'~', '.', 0xb7},	// · Vim 5.x compatible
 	{'\'', ',', 0xb8},
 	{'1', 'S', 0xb9},
-	{'1', '1', 0xb9},	//  Vim 5.x compatible
+	{'1', '1', 0xb9},	// ¹ Vim 5.x compatible
 	{'-', 'o', 0xba},
 	{'>', '>', 0xbb},
 	{'1', '4', 0xbc},
 	{'1', '2', 0xbd},
 	{'3', '4', 0xbe},
 	{'?', 'I', 0xbf},
-	{'~', '?', 0xbf},	//  Vim 5.x compatible
+	{'~', '?', 0xbf},	// ¿ Vim 5.x compatible
 	{'A', '!', 0xc0},
-	{'A', '`', 0xc0},	//  Vim 5.x compatible
+	{'A', '`', 0xc0},	// À Vim 5.x compatible
 	{'A', '\'', 0xc1},
 	{'A', '>', 0xc2},
-	{'A', '^', 0xc2},	//  Vim 5.x compatible
+	{'A', '^', 0xc2},	// Â Vim 5.x compatible
 	{'A', '?', 0xc3},
-	{'A', '~', 0xc3},	//  Vim 5.x compatible
+	{'A', '~', 0xc3},	// Ã Vim 5.x compatible
 	{'A', ':', 0xc4},
-	{'A', '"', 0xc4},	//  Vim 5.x compatible
+	{'A', '"', 0xc4},	// Ä Vim 5.x compatible
 	{'A', 'A', 0xc5},
-	{'A', '@', 0xc5},	//  Vim 5.x compatible
+	{'A', '@', 0xc5},	// Å Vim 5.x compatible
 	{'A', 'E', 0xc6},
 	{'C', ',', 0xc7},
 	{'E', '!', 0xc8},
-	{'E', '`', 0xc8},	//  Vim 5.x compatible
+	{'E', '`', 0xc8},	// È Vim 5.x compatible
 	{'E', '\'', 0xc9},
 	{'E', '>', 0xca},
-	{'E', '^', 0xca},	//  Vim 5.x compatible
+	{'E', '^', 0xca},	// Ê Vim 5.x compatible
 	{'E', ':', 0xcb},
-	{'E', '"', 0xcb},	//  Vim 5.x compatible
+	{'E', '"', 0xcb},	// Ë Vim 5.x compatible
 	{'I', '!', 0xcc},
-	{'I', '`', 0xcc},	//  Vim 5.x compatible
+	{'I', '`', 0xcc},	// Ì Vim 5.x compatible
 	{'I', '\'', 0xcd},
 	{'I', '>', 0xce},
-	{'I', '^', 0xce},	//  Vim 5.x compatible
+	{'I', '^', 0xce},	// Î Vim 5.x compatible
 	{'I', ':', 0xcf},
-	{'I', '"', 0xcf},	//  Vim 5.x compatible
+	{'I', '"', 0xcf},	// Ï Vim 5.x compatible
 	{'D', '-', 0xd0},
 	{'N', '?', 0xd1},
-	{'N', '~', 0xd1},	//  Vim 5.x compatible
+	{'N', '~', 0xd1},	// Ñ Vim 5.x compatible
 	{'O', '!', 0xd2},
-	{'O', '`', 0xd2},	//  Vim 5.x compatible
+	{'O', '`', 0xd2},	// Ò Vim 5.x compatible
 	{'O', '\'', 0xd3},
 	{'O', '>', 0xd4},
-	{'O', '^', 0xd4},	//  Vim 5.x compatible
+	{'O', '^', 0xd4},	// Ô Vim 5.x compatible
 	{'O', '?', 0xd5},
-	{'O', '~', 0xd5},	//  Vim 5.x compatible
+	{'O', '~', 0xd5},	// Õ Vim 5.x compatible
 	{'O', ':', 0xd6},
 	{'*', 'X', 0xd7},
-	{'/', '\\', 0xd7},	//  Vim 5.x compatible
+	{'/', '\\', 0xd7},	// × Vim 5.x compatible
 	{'O', '/', 0xd8},
 	{'U', '!', 0xd9},
-	{'U', '`', 0xd9},	//  Vim 5.x compatible
+	{'U', '`', 0xd9},	// Ù Vim 5.x compatible
 	{'U', '\'', 0xda},
 	{'U', '>', 0xdb},
-	{'U', '^', 0xdb},	//  Vim 5.x compatible
+	{'U', '^', 0xdb},	// Û Vim 5.x compatible
 	{'U', ':', 0xdc},
 	{'Y', '\'', 0xdd},
 	{'T', 'H', 0xde},
-	{'I', 'p', 0xde},	//  Vim 5.x compatible
+	{'I', 'p', 0xde},	// Þ Vim 5.x compatible
 	{'s', 's', 0xdf},
 	{'a', '!', 0xe0},
-	{'a', '`', 0xe0},	//  Vim 5.x compatible
+	{'a', '`', 0xe0},	// à Vim 5.x compatible
 	{'a', '\'', 0xe1},
 	{'a', '>', 0xe2},
-	{'a', '^', 0xe2},	//  Vim 5.x compatible
+	{'a', '^', 0xe2},	// â Vim 5.x compatible
 	{'a', '?', 0xe3},
-	{'a', '~', 0xe3},	//  Vim 5.x compatible
+	{'a', '~', 0xe3},	// ã Vim 5.x compatible
 	{'a', ':', 0xe4},
-	{'a', '"', 0xe4},	//  Vim 5.x compatible
+	{'a', '"', 0xe4},	// ä Vim 5.x compatible
 	{'a', 'a', 0xe5},
-	{'a', '@', 0xe5},	//  Vim 5.x compatible
+	{'a', '@', 0xe5},	// å Vim 5.x compatible
 	{'a', 'e', 0xe6},
 	{'c', ',', 0xe7},
 	{'e', '!', 0xe8},
-	{'e', '`', 0xe8},	//  Vim 5.x compatible
+	{'e', '`', 0xe8},	// è Vim 5.x compatible
 	{'e', '\'', 0xe9},
 	{'e', '>', 0xea},
-	{'e', '^', 0xea},	//  Vim 5.x compatible
+	{'e', '^', 0xea},	// ê Vim 5.x compatible
 	{'e', ':', 0xeb},
-	{'e', '"', 0xeb},	//  Vim 5.x compatible
+	{'e', '"', 0xeb},	// ë Vim 5.x compatible
 	{'i', '!', 0xec},
-	{'i', '`', 0xec},	//  Vim 5.x compatible
+	{'i', '`', 0xec},	// ì Vim 5.x compatible
 	{'i', '\'', 0xed},
 	{'i', '>', 0xee},
-	{'i', '^', 0xee},	//  Vim 5.x compatible
+	{'i', '^', 0xee},	// î Vim 5.x compatible
 	{'i', ':', 0xef},
 	{'d', '-', 0xf0},
 	{'n', '?', 0xf1},
-	{'n', '~', 0xf1},	//  Vim 5.x compatible
+	{'n', '~', 0xf1},	// ñ Vim 5.x compatible
 	{'o', '!', 0xf2},
-	{'o', '`', 0xf2},	//  Vim 5.x compatible
+	{'o', '`', 0xf2},	// ò Vim 5.x compatible
 	{'o', '\'', 0xf3},
 	{'o', '>', 0xf4},
-	{'o', '^', 0xf4},	//  Vim 5.x compatible
+	{'o', '^', 0xf4},	// ô Vim 5.x compatible
 	{'o', '?', 0xf5},
-	{'o', '~', 0xf5},	//  Vim 5.x compatible
+	{'o', '~', 0xf5},	// õ Vim 5.x compatible
 	{'o', ':', 0xf6},
 	{'-', ':', 0xf7},
 	{'o', '/', 0xf8},
 	{'u', '!', 0xf9},
-	{'u', '`', 0xf9},	//  Vim 5.x compatible
+	{'u', '`', 0xf9},	// ù Vim 5.x compatible
 	{'u', '\'', 0xfa},
 	{'u', '>', 0xfb},
-	{'u', '^', 0xfb},	//  Vim 5.x compatible
+	{'u', '^', 0xfb},	// û Vim 5.x compatible
 	{'u', ':', 0xfc},
 	{'y', '\'', 0xfd},
 	{'t', 'h', 0xfe},
@@ -2180,7 +2180,7 @@ listdigraphs(int use_headers)
 			       wrong, in which case we messed up ScreenLines */
 }
 
-struct dg_header_entry {
+static struct dg_header_entry {
     int	    dg_start;
     char    *dg_header;
 } header_table[] = {
