@@ -928,7 +928,7 @@ EXCMD(CMD_map,		"map",		ex_map,
 EXCMD(CMD_mapclear,	"mapclear",	ex_mapclear,
 	EX_EXTRA|EX_BANG|EX_TRLBAR|EX_CMDWIN,
 	ADDR_NONE),
-EXCMD(CMD_marks,	"marks",	do_marks,
+EXCMD(CMD_marks,	"marks",	ex_marks,
 	EX_EXTRA|EX_TRLBAR|EX_CMDWIN,
 	ADDR_NONE),
 EXCMD(CMD_match,	"match",	ex_match,
@@ -1378,9 +1378,6 @@ EXCMD(CMD_split,	"split",	ex_splitview,
 EXCMD(CMD_spellgood,	"spellgood",	ex_spell,
 	EX_BANG|EX_RANGE|EX_NEEDARG|EX_EXTRA|EX_TRLBAR,
 	ADDR_OTHER),
-EXCMD(CMD_spellrare,	"spellrare",	ex_spell,
-	EX_BANG|EX_RANGE|EX_NEEDARG|EX_EXTRA|EX_TRLBAR,
-	ADDR_OTHER),
 EXCMD(CMD_spelldump,	"spelldump",	ex_spelldump,
 	EX_BANG|EX_TRLBAR,
 	ADDR_NONE),
@@ -1390,6 +1387,9 @@ EXCMD(CMD_spellinfo,	"spellinfo",	ex_spellinfo,
 EXCMD(CMD_spellrepall,	"spellrepall",	ex_spellrepall,
 	EX_TRLBAR,
 	ADDR_NONE),
+EXCMD(CMD_spellrare,	"spellrare",	ex_spell,
+	EX_BANG|EX_RANGE|EX_NEEDARG|EX_EXTRA|EX_TRLBAR,
+	ADDR_OTHER),
 EXCMD(CMD_spellundo,	"spellundo",	ex_spell,
 	EX_BANG|EX_RANGE|EX_NEEDARG|EX_EXTRA|EX_TRLBAR,
 	ADDR_OTHER),
