@@ -1,4 +1,4 @@
-/* vi:set ts=8 sts=4 sw=4:
+/* vi:set ts=8 sts=4 sw=4 noet:
  *
  * CSCOPE support for Vim added by Andy Kahn <kahn@zk3.dec.com>
  * Ported to Win32 by Sergey Khorev <sergey.khorev@gmail.com>
@@ -11,16 +11,11 @@
 
 #if defined(FEAT_CSCOPE) || defined(PROTO)
 
-#if defined(UNIX)
-# include <sys/types.h>		/* pid_t */
-# include <sys/stat.h>		/* dev_t, ino_t */
-#else
-# if defined (WIN32)
-#  ifndef WIN32_LEAN_AND_MEAN
-#   define WIN32_LEAN_AND_MEAN
-#  endif
-#  include <windows.h>
+#if defined (MSWIN)
+# ifndef WIN32_LEAN_AND_MEAN
+#  define WIN32_LEAN_AND_MEAN
 # endif
+# include <windows.h>
 #endif
 
 #define CSCOPE_SUCCESS		0
@@ -30,21 +25,12 @@
 #define	CSCOPE_PROMPT		">> "
 
 /*
- * s 0name	Find this C symbol
- * g 1name	Find this definition
- * d 2name	Find functions called by this function
- * c 3name	Find functions calling this function
- * t 4string	find text string (cscope 12.9)
- * t 4name	Find assignments to (cscope 13.3)
- *   5pattern	change pattern -- NOT USED
- * e 6pattern	Find this egrep pattern
- * f 7name	Find this file
- * i 8name	Find files #including this file
+ * See ":help cscope-find" for the possible queries.
  */
 
 typedef struct {
     char *  name;
-    int     (*func) __ARGS((exarg_T *eap));
+    int     (*func)(exarg_T *eap);
     char *  help;
     char *  usage;
     int	    cansplit;		/* if supports splitting window */
@@ -59,7 +45,7 @@ typedef struct csi {
     dev_t	    st_dev;	/* ID of dev containing cscope db */
     ino_t	    st_ino;	/* inode number of cscope db */
 #else
-# if defined(WIN32)
+# if defined(MSWIN)
     DWORD	    pid;	/* PID of the connected cscope process. */
     HANDLE	    hProc;	/* cscope process handle */
     DWORD	    nVolume;	/* Volume serial number, instead of st_dev */
