@@ -1,5 +1,6 @@
 #include "vterm_internal.h"
 
+// vim: set sw=2 :
 #include <stdio.h>
 #include <string.h>
 
@@ -9,10 +10,10 @@
 #define UNICODE_SPACE 0x20
 #define UNICODE_LINEFEED 0x0a
 
-/* State of the pen at some moment in time, also used in a cell */
+// State of the pen at some moment in time, also used in a cell
 typedef struct
 {
-  /* After the bitfield */
+  // After the bitfield
   VTermColor   fg, bg;
 
   unsigned int bold      : 1;
@@ -21,15 +22,15 @@ typedef struct
   unsigned int blink     : 1;
   unsigned int reverse   : 1;
   unsigned int strike    : 1;
-  unsigned int font      : 4; /* 0 to 9 */
+  unsigned int font      : 4; // 0 to 9
 
-  /* Extra state storage that isn't strictly pen-related */
+  // Extra state storage that isn't strictly pen-related
   unsigned int protected_cell : 1;
-  unsigned int dwl            : 1; /* on a DECDWL or DECDHL line */
-  unsigned int dhl            : 2; /* on a DECDHL line (1=top 2=bottom) */
+  unsigned int dwl            : 1; // on a DECDWL or DECDHL line
+  unsigned int dhl            : 2; // on a DECDHL line (1=top 2=bottom)
 } ScreenPen;
 
-/* Internal representation of a screen cell */
+// Internal representation of a screen cell
 typedef struct
 {
   uint32_t chars[VTERM_MAX_CHARS_PER_CELL];
@@ -47,7 +48,7 @@ struct VTermScreen
   void *cbdata;
 
   VTermDamageSize damage_merge;
-  /* start_row == -1 => no damage */
+  // start_row == -1 => no damage
   VTermRect damaged;
   VTermRect pending_scrollrect;
   int pending_scroll_downward, pending_scroll_rightward;
@@ -56,13 +57,13 @@ struct VTermScreen
   int cols;
   int global_reverse;
 
-  /* Primary and Altscreen. buffers[1] is lazily allocated as needed */
+  // Primary and Altscreen. buffers[1] is lazily allocated as needed
   ScreenCell *buffers[2];
 
-  /* buffer will == buffers[0] or buffers[1], depending on altscreen */
+  // buffer will == buffers[0] or buffers[1], depending on altscreen
   ScreenCell *buffer;
 
-  /* buffer for a single screen row used in scrollback storage callbacks */
+  // buffer for a single screen row used in scrollback storage callbacks
   VTermScreenCell *sb_buffer;
 
   ScreenPen pen;
@@ -74,6 +75,8 @@ static ScreenCell *getcell(const VTermScreen *screen, int row, int col)
     return NULL;
   if(col < 0 || col >= screen->cols)
     return NULL;
+  if (screen->buffer == NULL)
+    return NULL;
   return screen->buffer + (screen->cols * row) + col;
 }
 
@@ -82,6 +85,8 @@ static ScreenCell *realloc_buffer(VTermScreen *screen, ScreenCell *buffer, int n
   ScreenCell *new_buffer = vterm_allocator_malloc(screen->vt, sizeof(ScreenCell) * new_rows * new_cols);
   int row, col;
 
+  if (new_buffer == NULL)
+    return NULL;
   for(row = 0; row < new_rows; row++) {
     for(col = 0; col < new_cols; col++) {
       ScreenCell *new_cell = new_buffer + row*new_cols + col;
@@ -95,8 +100,7 @@ static ScreenCell *realloc_buffer(VTermScreen *screen, ScreenCell *buffer, int n
     }
   }
 
-  if(buffer)
-    vterm_allocator_free(screen->vt, buffer);
+  vterm_allocator_free(screen->vt, buffer);
 
   return new_buffer;
 }
@@ -107,25 +111,25 @@ static void damagerect(VTermScreen *screen, VTermRect rect)
 
   switch(screen->damage_merge) {
   case VTERM_DAMAGE_CELL:
-    /* Always emit damage event */
+    // Always emit damage event
     emit = rect;
     break;
 
   case VTERM_DAMAGE_ROW:
-    /* Emit damage longer than one row. Try to merge with existing damage in
-     * the same row */
+    // Emit damage longer than one row. Try to merge with existing damage in
+    // the same row
     if(rect.end_row > rect.start_row + 1) {
-      /* Bigger than 1 line - flush existing, emit this */
+      // Bigger than 1 line - flush existing, emit this
       vterm_screen_flush_damage(screen);
       emit = rect;
     }
     else if(screen->damaged.start_row == -1) {
-      /* None stored yet */
+      // None stored yet
       screen->damaged = rect;
       return;
     }
     else if(rect.start_row == screen->damaged.start_row) {
-      /* Merge with the stored line */
+      // Merge with the stored line
       if(screen->damaged.start_col > rect.start_col)
         screen->damaged.start_col = rect.start_col;
       if(screen->damaged.end_col < rect.end_col)
@@ -133,7 +137,7 @@ static void damagerect(VTermScreen *screen, VTermRect rect)
       return;
     }
     else {
-      /* Emit the currently stored line, store a new one */
+      // Emit the currently stored line, store a new one
       emit = screen->damaged;
       screen->damaged = rect;
     }
@@ -141,7 +145,7 @@ static void damagerect(VTermScreen *screen, VTermRect rect)
 
   case VTERM_DAMAGE_SCREEN:
   case VTERM_DAMAGE_SCROLL:
-    /* Never emit damage event */
+    // Never emit damage event
     if(screen->damaged.start_row == -1)
       screen->damaged = rect;
     else {
@@ -208,9 +212,9 @@ static int moverect_internal(VTermRect dest, VTermRect src, void *user)
   VTermScreen *screen = user;
 
   if(screen->callbacks && screen->callbacks->sb_pushline &&
-     dest.start_row == 0 && dest.start_col == 0 &&  /* starts top-left corner */
-     dest.end_col == screen->cols &&                /* full width */
-     screen->buffer == screen->buffers[0]) {        /* not altscreen */
+     dest.start_row == 0 && dest.start_col == 0 &&  // starts top-left corner
+     dest.end_col == screen->cols &&                // full width
+     screen->buffer == screen->buffers[0]) {        // not altscreen
     VTermPos pos;
     for(pos.row = 0; pos.row < src.start_row; pos.row++) {
       for(pos.col = 0; pos.col < screen->cols; pos.col++)
@@ -252,7 +256,7 @@ static int moverect_user(VTermRect dest, VTermRect src, void *user)
 
   if(screen->callbacks && screen->callbacks->moverect) {
     if(screen->damage_merge != VTERM_DAMAGE_SCROLL)
-      /* Avoid an infinite loop */
+      // Avoid an infinite loop
       vterm_screen_flush_damage(screen);
 
     if((*screen->callbacks->moverect)(dest, src, screen->cbdata))
@@ -350,15 +354,14 @@ static int scrollrect(VTermRect rect, int downward, int rightward, void *user)
     return 1;
 
   if(rect_contains(&rect, &screen->damaged)) {
-    /* Scroll region entirely contains the damage; just move it */
+    // Scroll region entirely contains the damage; just move it
     vterm_rect_move(&screen->damaged, -downward, -rightward);
     rect_clip(&screen->damaged, &rect);
   }
-  /* There are a number of possible cases here, but lets restrict this to only
-   * the common case where we might actually gain some performance by
-   * optimising it. Namely, a vertical scroll that neatly cuts the damage
-   * region in half.
-   */
+  // There are a number of possible cases here, but lets restrict this to only
+  // the common case where we might actually gain some performance by
+  // optimising it. Namely, a vertical scroll that neatly cuts the damage
+  // region in half.
   else if(rect.start_col <= screen->damaged.start_col &&
           rect.end_col   >= screen->damaged.end_col &&
           rightward == 0) {
@@ -429,6 +432,9 @@ static int setpenattr(VTermAttr attr, VTermValue *val, void *user)
   case VTERM_ATTR_BACKGROUND:
     screen->pen.bg = val->color;
     return 1;
+
+  case VTERM_N_ATTRS:
+    return 0;
   }
 
   return 0;
@@ -444,9 +450,8 @@ static int settermprop(VTermProp prop, VTermValue *val, void *user)
       return 0;
 
     screen->buffer = val->boolean ? screen->buffers[1] : screen->buffers[0];
-    /* only send a damage event on disable; because during enable there's an
-     * erase that sends a damage anyway
-     */
+    // only send a damage event on disable; because during enable there's an
+    // erase that sends a damage anyway
     if(!val->boolean)
       damagescreen(screen);
     break;
@@ -455,7 +460,7 @@ static int settermprop(VTermProp prop, VTermValue *val, void *user)
     damagescreen(screen);
     break;
   default:
-    ; /* ignore */
+    ; // ignore
   }
 
   if(screen->callbacks && screen->callbacks->settermprop)
@@ -485,11 +490,11 @@ static int resize(int new_rows, int new_cols, VTermPos *delta, void *user)
   int first_blank_row;
 
   if(!is_altscreen && new_rows < old_rows) {
-    /* Fewer rows - determine if we're going to scroll at all, and if so, push
-       those lines to scrollback */
+    // Fewer rows - determine if we're going to scroll at all, and if so, push
+    // those lines to scrollback
     VTermPos pos = { 0, 0 };
     VTermPos cursor = screen->state->pos;
-    /* Find the first blank row after the cursor. */
+    // Find the first blank row after the cursor.
     for(pos.row = old_rows - 1; pos.row >= new_rows; pos.row--)
       if(!vterm_screen_is_eol(screen, pos) || cursor.row == pos.row)
         break;
@@ -515,8 +520,7 @@ static int resize(int new_rows, int new_cols, VTermPos *delta, void *user)
   screen->rows = new_rows;
   screen->cols = new_cols;
 
-  if(screen->sb_buffer)
-    vterm_allocator_free(screen->vt, screen->sb_buffer);
+  vterm_allocator_free(screen->vt, screen->sb_buffer);
 
   screen->sb_buffer = vterm_allocator_malloc(screen->vt, sizeof(VTermScreenCell) * new_cols);
 
@@ -603,29 +607,34 @@ static int setlineinfo(int row, const VTermLineInfo *newinfo, const VTermLineInf
 }
 
 static VTermStateCallbacks state_cbs = {
-  &putglyph, /* putglyph */
-  &movecursor, /* movecursor */
-  &scrollrect, /* scrollrect */
-  NULL, /* moverect */
-  &erase, /* erase */
-  NULL, /* initpen */
-  &setpenattr, /* setpenattr */
-  &settermprop, /* settermprop */
-  &bell, /* bell */
-  &resize, /* resize */
-  &setlineinfo /* setlineinfo */
+  &putglyph, // putglyph
+  &movecursor, // movecursor
+  &scrollrect, // scrollrect
+  NULL, // moverect
+  &erase, // erase
+  NULL, // initpen
+  &setpenattr, // setpenattr
+  &settermprop, // settermprop
+  &bell, // bell
+  &resize, // resize
+  &setlineinfo // setlineinfo
 };
 
+/*
+ * Allocate a new screen and return it.
+ * Return NULL when out of memory.
+ */
 static VTermScreen *screen_new(VTerm *vt)
 {
   VTermState *state = vterm_obtain_state(vt);
   VTermScreen *screen;
   int rows, cols;
 
-  if(!state)
+  if (state == NULL)
     return NULL;
-
   screen = vterm_allocator_malloc(vt, sizeof(VTermScreen));
+  if (screen == NULL)
+    return NULL;
 
   vterm_get_size(vt, &rows, &cols);
 
@@ -643,10 +652,13 @@ static VTermScreen *screen_new(VTerm *vt)
   screen->cbdata    = NULL;
 
   screen->buffers[0] = realloc_buffer(screen, NULL, rows, cols);
-
   screen->buffer = screen->buffers[0];
-
   screen->sb_buffer = vterm_allocator_malloc(screen->vt, sizeof(VTermScreenCell) * cols);
+  if (screen->buffer == NULL || screen->sb_buffer == NULL)
+  {
+    vterm_screen_free(screen);
+    return NULL;
+  }
 
   vterm_state_set_callbacks(screen->state, &state_cbs, screen);
 
@@ -656,11 +668,8 @@ static VTermScreen *screen_new(VTerm *vt)
 INTERNAL void vterm_screen_free(VTermScreen *screen)
 {
   vterm_allocator_free(screen->vt, screen->buffers[0]);
-  if(screen->buffers[1])
-    vterm_allocator_free(screen->vt, screen->buffers[1]);
-
+  vterm_allocator_free(screen->vt, screen->buffers[1]);
   vterm_allocator_free(screen->vt, screen->sb_buffer);
-
   vterm_allocator_free(screen->vt, screen);
 }
 
@@ -699,10 +708,10 @@ static size_t _get_chars(const VTermScreen *screen, const int utf8, void *buffer
       int i;
 
       if(cell->chars[0] == 0)
-        /* Erased cell, might need a space */
+        // Erased cell, might need a space
         padding++;
       else if(cell->chars[0] == (uint32_t)-1)
-        /* Gap behind a double-width char, do nothing */
+        // Gap behind a double-width char, do nothing
         ;
       else {
         while(padding) {
@@ -734,7 +743,7 @@ size_t vterm_screen_get_text(const VTermScreen *screen, char *str, size_t len, c
   return _get_chars(screen, 1, str, len, rect);
 }
 
-/* Copy internal to external representation of a screen cell */
+// Copy internal to external representation of a screen cell
 int vterm_screen_get_cell(const VTermScreen *screen, VTermPos pos, VTermScreenCell *cell)
 {
   ScreenCell *intcell = getcell(screen, pos.row, pos.col);
@@ -763,16 +772,33 @@ int vterm_screen_get_cell(const VTermScreen *screen, VTermPos pos, VTermScreenCe
   cell->fg = intcell->pen.fg;
   cell->bg = intcell->pen.bg;
 
-  if(pos.col < (screen->cols - 1) &&
-     getcell(screen, pos.row, pos.col + 1)->chars[0] == (uint32_t)-1)
-    cell->width = 2;
-  else
-    cell->width = 1;
+  if(vterm_get_special_pty_type() == 2) {
+    /* Get correct cell width from cell information contained in line buffer */
+    if(pos.col < (screen->cols - 1) &&
+       getcell(screen, pos.row, pos.col + 1)->chars[0] == (uint32_t)-1) {
+      if(getcell(screen, pos.row, pos.col)->chars[0] == 0x20) {
+        getcell(screen, pos.row, pos.col)->chars[0] = 0;
+        cell->width = 2;
+      } else if(getcell(screen, pos.row, pos.col)->chars[0] == 0) {
+        getcell(screen, pos.row, pos.col + 1)->chars[0] = 0;
+        cell->width = 1;
+      } else {
+        cell->width = 2;
+      }
+    } else
+      cell->width = 1;
+  } else {
+    if(pos.col < (screen->cols - 1) &&
+       getcell(screen, pos.row, pos.col + 1)->chars[0] == (uint32_t)-1)
+      cell->width = 2;
+    else
+      cell->width = 1;
+  }
 
   return 1;
 }
 
-/* Copy external to internal representation of a screen cell */
+// Copy external to internal representation of a screen cell
 /* static because it's only used internally for sb_popline during resize */
 static int vterm_screen_set_cell(VTermScreen *screen, VTermPos pos, const VTermScreenCell *cell)
 {
@@ -807,7 +833,7 @@ static int vterm_screen_set_cell(VTermScreen *screen, VTermPos pos, const VTermS
 
 int vterm_screen_is_eol(const VTermScreen *screen, VTermPos pos)
 {
-  /* This cell is EOL if this and every cell to the right is black */
+  // This cell is EOL if this and every cell to the right is black
   for(; pos.col < screen->cols; pos.col++) {
     ScreenCell *cell = getcell(screen, pos.row, pos.col);
     if(cell->chars[0] != 0)
@@ -909,7 +935,7 @@ int vterm_screen_get_attrs_extent(const VTermScreen *screen, VTermRect *extent,
 
   ScreenCell *target = getcell(screen, pos.row, pos.col);
 
-  /* TODO: bounds check */
+  // TODO: bounds check
   extent->start_row = pos.row;
   extent->end_row   = pos.row + 1;
 
