@@ -272,7 +272,7 @@ mch_input_isatty(void)
     void
 mch_settitle(
     char_u *title,
-    char_u *icon)
+    char_u *icon UNUSED)
 {
 # ifdef FEAT_GUI_MSWIN
 #  ifdef VIMDLL
@@ -1164,7 +1164,7 @@ AbortProc(HDC hdcPrn UNUSED, int iCode UNUSED)
 PrintHookProc(
 	HWND hDlg,	// handle to dialog box
 	UINT uiMsg,	// message identifier
-	WPARAM wParam,	// message parameter
+	WPARAM wParam UNUSED,	// message parameter
 	LPARAM lParam	// message parameter
 	)
 {
@@ -1654,7 +1654,7 @@ mch_print_text_out(char_u *p, int len)
     /* This is wrong when printing spaces for a TAB. */
     if (p[len] != NUL)
     {
-	wlen = MB_PTR2LEN(p + len);
+	wlen = mb_ptr2len(p + len);
 	wp = enc_to_utf16(p + len, &wlen);
 	if (wp != NULL)
 	{
