@@ -65,7 +65,9 @@ enum SpecialKey
     KS_KS,	/* put term in "keypad transmit" mode */
     KS_KE,	/* out of "keypad transmit" mode */
     KS_TI,	/* put terminal in termcap mode */
-    KS_TE,	/* out of termcap mode */
+    KS_CTI,	/* put terminal in "raw" mode */
+    KS_TE,	/* end of termcap mode */
+    KS_CTE,	/* end of "raw" mode */
     KS_BC,	/* backspace character (cursor left) */
     KS_CCS,	/* cur is relative to scroll region */
     KS_CCO,	/* number of colors */
@@ -101,10 +103,14 @@ enum SpecialKey
     KS_CBE,	/* enable bracketed paste mode */
     KS_CBD,	/* disable bracketed paste mode */
     KS_CPS,	/* start of bracketed paste */
-    KS_CPE	/* end of bracketed paste */
+    KS_CPE,	/* end of bracketed paste */
+    KS_CST,	/* save window title */
+    KS_CRT,	/* restore window title */
+    KS_SSI,	/* save icon text */
+    KS_SRI	/* restore icon text */
 };
 
-#define KS_LAST	    KS_CPE
+#define KS_LAST	    KS_SRI
 
 /*
  * the terminal capabilities are stored in this array
@@ -160,7 +166,9 @@ extern char_u *(term_strings[]);    /* current terminal strings */
 #define T_KS	(TERM_STR(KS_KS))	/* put term in "keypad transmit" mode */
 #define T_KE	(TERM_STR(KS_KE))	/* out of "keypad transmit" mode */
 #define T_TI	(TERM_STR(KS_TI))	/* put terminal in termcap mode */
-#define T_TE	(TERM_STR(KS_TE))	/* out of termcap mode */
+#define T_CTI	(TERM_STR(KS_CTI))	/* put terminal in "raw" mode */
+#define T_TE	(TERM_STR(KS_TE))	/* end of termcap mode */
+#define T_CTE	(TERM_STR(KS_CTE))	/* end of "raw" mode */
 #define T_BC	(TERM_STR(KS_BC))	/* backspace character */
 #define T_CCS	(TERM_STR(KS_CCS))	/* cur is relative to scroll region */
 #define T_CCO	(TERM_STR(KS_CCO))	/* number of colors */
@@ -196,6 +204,10 @@ extern char_u *(term_strings[]);    /* current terminal strings */
 #define T_BD	(TERM_STR(KS_CBD))	/* disable bracketed paste mode */
 #define T_PS	(TERM_STR(KS_CPS))	/* start of bracketed paste */
 #define T_PE	(TERM_STR(KS_CPE))	/* end of bracketed paste */
+#define T_CST	(TERM_STR(KS_CST))	/* save window title */
+#define T_CRT	(TERM_STR(KS_CRT))	/* restore window title */
+#define T_SSI	(TERM_STR(KS_SSI))	/* save icon text */
+#define T_SRI	(TERM_STR(KS_SRI))	/* restore icon text */
 
 #define TMODE_COOK  0	/* terminal mode for external cmds and Ex mode */
 #define TMODE_SLEEP 1	/* terminal mode for sleeping (cooked but no echo) */
